@@ -22,15 +22,15 @@ sub class_methods : Tests(+1) {
     # got from Data::Dumper
     my $parsed_data = {
         'siebel1' => {
-            'sblsrvr_state'  => 'Running',
-            'sblsrvr_status' => '8.0.0.2 [20412] LANG_INDEPENDENT',
-            'start_time'     => '2013-12-08 17:11:25',
-            'install_dir' => '/opt/oracle/app/product/8.0.0/siebel_1/siebsrvr',
-            'sblmgr_pid'  => '3206',
-            'sv_disp_state'      => 'Running',
-            'end_time'           => '',
-            'sblsrvr_group_name' => '',
-            'host_name'          => 'siebel1'
+            'SBLSRVR_STATE'  => 'Running',
+            'SBLSRVR_STATUS' => '8.0.0.2 [20412] LANG_INDEPENDENT',
+            'START_TIME'     => '2013-12-08 17:11:25',
+            'INSTALL_DIR' => '/opt/oracle/app/product/8.0.0/siebel_1/siebsrvr',
+            'SBLMGR_PID'  => '3206',
+            'SV_DISP_STATE'      => 'Running',
+            'END_TIME'           => '',
+            'SBLSRVR_GROUP_NAME' => '',
+            'HOST_NAME'          => 'siebel1'
           }
     };
 
